
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.18.8.post1',
    'branch_nick': '(HEAD',
    'revision_id': 'd16f9c17338bbb29386d7cdd91009c4d14589115',
    'revno': 7391
}
